open source and free to use!!<br>
if you have question,feel free to email seojin04230423@gmail.com !<br>
Changelogs:<br>
0.0.0b1 first release(changed from percstat)<br>
0.0.0b3 debug and added AmB function<br>
0.0.0b4 import error fixed<br>
how to use:<br>
1.Class etc:<br>
coin=[0,1]<br>
dice=[1,2,3,4,5,6]<br>
2.Class percentage:<br>
2-1.functions that returns integer:<br>
Factorial(n)=n\*(n-1)\*...\*2\*1<br>
nPr(n,r)=n!/(n-r)!(! is factorial)<br>
nPIr(n,r)=n\*\*r((ex)nPIr(3,2)=3\*\*2= 3\*3,nPIr(4,4)=4\*\*4=4\*4\*4\*4<br> 
nHr(n,r)=n+r-1Cr(=nCr(n+r-1,r))<br>
nCr(n,r)=nPr(=nPr(n,r))/n!<br>
P(A,S)=len(A)/len(S)(if A is in S,if not, returns 0)(A and S are NON-TUPLE list)<br>
P\_BlA(A,B,S)=returns P(AnB(A,B)/P(A))<br>
2-2.functions that returns NON-TUPLE list:<br>
Ac(A,S)=returns all of S's elements except A's elements.<br>
AnB(A,B)=returns (A and B)'s elements.<br>
AUB(A,B)=returns (A or B')s elements.<br>
AmB(A,B,S)=returns AnB(A,Ac(B,S))'s elements.<br>
2-3.Functions that returns boolean(True/False)<br>
AcB(A,B)=returns true if list A is in B<br>
AEB(A,B)=returns true if element A(only one elements!) is in B<br>
	 
